FlutterExitApp class
Provides access to the native platform's exit app functionality.
This plugin allows you to exit your Flutter application using
platform-specific native methods instead of calling exit(0) in Dart.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- channel ↔ MethodChannel
-
The method channel used to communicate with native platforms.
Exposed for testing purposes only.
getter/setter pair
-
platformVersion
→ Future<
String?> -
Gets the platform version.
no setter